# coding: utf-8
require 'test/unit'
require 'DavinciRubyClientSDK'

class TestDavinciRubyClientSDK < Test::Unit::TestCase


  def test_blueprint_hash_in
    assert = [{:layer => 1, :technique => 'draw_image', :inspiration => {:test=>"a"}}]

    result = DavinciRubyClientSDK::Blueprint::new('aa')
    result.add_layer 1 do |layer|
      layer.technique      = :draw_image
      layer.inspiration    = {:test=>"a"}
    end

    result = result.layers

    assert_equal assert, result
  end

  def test_blueprint_one_step_in
    assert = [{:layer => 1, :technique => 'draw_image', :inspiration => {:test=>"a"}}]

    result = DavinciRubyClientSDK::Blueprint::new('aa')
    result.add_layer 1 do |layer|
      layer.technique = :draw_image
      layer.add_inspiration :test, 'a'
    end
    result = result.layers

    assert_equal assert, result
  end

  def test_canvas
    assert = {:width => 100}

    result = DavinciRubyClientSDK::Blueprint::new('aa')
    result.canvas do |option|
      option.add_canvas_option :width, 100
    end

    result = result.canvas

    assert_equal assert, result
  end

  def test_mount
    assert = {:ext => 'jpg'}

    result = DavinciRubyClientSDK::Blueprint::new('aa')
    result.mount do |option|
      option.add_mount_option :ext, 'jpg'
    end

    result = result.mount

    assert_equal assert, result
  end

  def test_draw_sync
    DavinciRubyClientSDK::Setting.app_key = '123'
    DavinciRubyClientSDK::Setting.app_secret = '123'
    DavinciRubyClientSDK::Setting.server_address = 'http://127.0.0.1:9000'

    blueprints = Array.new

    blueprints << {:test => 'test'}

    api = DavinciRubyClientSDK::API.new
    error, result = api.draw('label', blueprints).call

    p error
    p result
  end

  def test_api_get
    DavinciRubyClientSDK::Setting.app_key = '123'
    DavinciRubyClientSDK::Setting.app_secret = '123'
    DavinciRubyClientSDK::Setting.server_address = 'http://127.0.0.1:9000'

    blueprints = {:test => 'test', :p => 111}

    api = DavinciRubyClientSDK::API.new
    error, result = api.get('/font/list', blueprints).call

    p error
    p result
  end

  def test_receiver
    DavinciRubyClientSDK::Setting.app_key = 'memeing'
    DavinciRubyClientSDK::Setting.app_secret = 'xE7xkJhvy7cHxuI'
    DavinciRubyClientSDK::Setting.server_address = 'http://davinci.memeing.cn'
  end


  #receiver test
  #require 'webrick'
  #
  #inclue WEBrick
  #
  #log = [[ $stderr, WEBrick::AccessLog::COMMON_LOG_FORMAT + ' POST=%{body}n' + 'HEADER=%{header}n']]
  #
  #server = WEBrick::HTTPServer.new :Port => 9000, :AccessLog => log
  #server.mount_proc '/' do |req, res|
  #  req.attributes['body']   = req.body
  #  req.attributes['header'] = req.header
  #  res.body = "Web server response:\n"
  #end
  #server.start


end